@@ -1,7 +1,7 @@
 //
 // $Source: /cvsroot/gambit/gambit/sources/gui/dlabout.h,v $
-// $Date: 2002/08/27 20:29:25 $
-// $Revision: 1.4 $
+// $Date: 2005/12/12 07:17:05 $
+// $Revision: 1.5 $
 //
 // DESCRIPTION:
 // Declaration of "about" dialog
@@ -27,13 +27,10 @@
 #ifndef DLABOUT_H
 #define DLABOUT_H
 
-#include "wx/wx.h"
-
-class dialogAbout : public wxDialog {
+class gbtAboutDialog : public wxDialog {
 public:
-  dialogAbout(wxWindow *p_parent, const wxString &p_title,
-	      const wxString &p_programName, const wxString &p_versionString);
-  virtual ~dialogAbout() { }
+  gbtAboutDialog(wxWindow *p_parent);
+  virtual ~gbtAboutDialog() { }
 };
 
 #endif  // DLABOUT_H
