@@ -1,7 +1,7 @@
 //
 // $Source: /cvsroot/gambit/gambit/sources/gui/dleditnode.cc,v $
-// $Date: 2004/08/17 17:53:50 $
-// $Revision: 1.7.2.3 $
+// $Date: 2006/01/06 19:34:45 $
+// $Revision: 1.37 $
 //
 // DESCRIPTION:
 // Dialog for viewing and editing properties of a node
@@ -24,30 +24,28 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
 
-#include "wx/wxprec.h"
+#include <wx/wxprec.h>
 #ifndef WX_PRECOMP
-#include "wx/wx.h"
+#include <wx/wx.h>
 #endif  // WX_PRECOMP
-#include "game/efg.h"
+#include "libgambit/libgambit.h"
 #include "dleditnode.h"
 
 //======================================================================
 //                      class dialogEditNode
 //======================================================================
 
-dialogEditNode::dialogEditNode(wxWindow *p_parent, Node *p_node)
+dialogEditNode::dialogEditNode(wxWindow *p_parent, Gambit::GameNode p_node)
   : wxDialog(p_parent, -1, _("Node properties"), wxDefaultPosition), 
     m_node(p_node)
 {
-  SetAutoLayout(true);
-
   wxBoxSizer *topSizer = new wxBoxSizer(wxVERTICAL);
 
   wxBoxSizer *labelSizer = new wxBoxSizer(wxHORIZONTAL);
   labelSizer->Add(new wxStaticText(this, wxID_STATIC, _("Node label")),
 		  0, wxALL | wxCENTER, 5);
   m_nodeName = new wxTextCtrl(this, -1, 
-			      wxString::Format(_T("%s"), (const char *) m_node->GetName()));
+			      wxString(m_node->GetLabel().c_str(), *wxConvCurrent));
   labelSizer->Add(m_nodeName, 1, wxALL | wxCENTER | wxEXPAND, 5);
   topSizer->Add(labelSizer, 0, wxALL | wxEXPAND, 5);
 
@@ -57,21 +55,40 @@ dialogEditNode::dialogEditNode(wxWindow *p_parent, Node *p_node)
   m_infoset = new wxChoice(this, -1);
   if (p_node->NumChildren() > 0) {
     m_infoset->Append(_("New information set"));
-    gBlock<Infoset *> infosets = p_node->Game()->Infosets();
-    int selection = 0;
-    for (int iset = 1; iset <= infosets.Length(); iset++) {
-      if (!infosets[iset]->IsChanceInfoset() &&
-	  infosets[iset]->NumActions() == p_node->NumChildren()) {
-	m_infosetList.Append(infosets[iset]);
-	m_infoset->Append(wxString::Format(_("Player %d, Infoset %d"),
-			  infosets[iset]->GetPlayer()->GetNumber(),
-			  infosets[iset]->GetNumber()));
-	if (infosets[iset] == p_node->GetInfoset()) {
-	  selection = m_infosetList.Length();
+    if (p_node->GetInfoset()->IsChanceInfoset()) {
+      int selection = 0;
+      for (int iset = 1; iset <= p_node->GetGame()->GetChance()->NumInfosets();
+	   iset++) {
+	Gambit::GameInfoset infoset = p_node->GetGame()->GetChance()->GetInfoset(iset);
+	if (infoset->NumActions() == p_node->NumChildren()) {
+	  m_infosetList.Append(infoset);
+	  m_infoset->Append(wxString::Format(_("Chance infoset %d"),
+					     infoset->GetNumber()));
+	  if (infoset == p_node->GetInfoset()) {
+	    selection = m_infosetList.Length();
+	  }
 	}
       }
+      m_infoset->SetSelection(selection);
+    }
+    else {
+      int selection = 0;
+      for (int pl = 1; pl <= p_node->GetGame()->NumPlayers(); pl++) {
+	Gambit::GamePlayer player = p_node->GetGame()->GetPlayer(pl);
+	for (int iset = 1; iset <= player->NumInfosets(); iset++) {
+	  Gambit::GameInfoset infoset = player->GetInfoset(iset);
+	  if (infoset->NumActions() == p_node->NumChildren()) {
+	    m_infosetList.Append(infoset);
+	    m_infoset->Append(wxString::Format(_("Player %d, Infoset %d"),
+					       pl, iset));
+	    if (infoset == p_node->GetInfoset()) {
+	      selection = m_infosetList.Length();
+	    }
+	  }
+	}
+      }
+      m_infoset->SetSelection(selection);
     }
-    m_infoset->SetSelection(selection);
   }
   else {
     m_infoset->Append(_("(none)"));
@@ -87,13 +104,10 @@ dialogEditNode::dialogEditNode(wxWindow *p_parent, Node *p_node)
 				       _("This is the root node of the tree")),
 		      0, wxALL | wxCENTER, 5);
   }
-  else if (p_node->Game()->IsLegalSubgame(p_node)) {
+  else if (p_node->IsSubgameRoot()) {
     subgameSizer->Add(new wxStaticText(this, wxID_STATIC,
 				       _("This is the root of a proper subgame")),
 		      0, wxALL | wxCENTER, 5);
-    m_markedSubgame = new wxCheckBox(this, -1, _("Subgame is marked"));
-    m_markedSubgame->SetValue(p_node->GetSubgameRoot() == p_node);
-    subgameSizer->Add(m_markedSubgame, 0, wxALL | wxCENTER, 0);
   }
   topSizer->Add(subgameSizer, 0, wxALL | wxCENTER, 5);
 
@@ -103,19 +117,20 @@ dialogEditNode::dialogEditNode(wxWindow *p_parent, Node *p_node)
   m_outcome = new wxChoice(this, -1);
   m_outcome->Append(_("(null)"));
   m_outcome->SetSelection(0);
-  const efgGame &efg = *p_node->Game();
-  for (int outc = 1; outc <= efg.NumOutcomes(); outc++) {
-    efgOutcome *outcome = efg.GetOutcome(outc);
-    gText item = ToText(outc) + ": " + efg.GetOutcomeName(outcome);
+  Gambit::Game efg = p_node->GetGame();
+  for (int outc = 1; outc <= efg->NumOutcomes(); outc++) {
+    Gambit::GameOutcome outcome = efg->GetOutcome(outc);
+    std::string item = Gambit::ToText(outc) + ": " + outcome->GetLabel();
     if (item == "") {
-      item = "Outcome" + ToText(outc);
+      item = "Outcome" + Gambit::ToText(outc);
     }
 
-    item += (" (" + ToText(efg.Payoff(outcome, efg.Players()[1])) + ", " +
-	     ToText(efg.Payoff(outcome, efg.Players()[2])));
-    if (efg.NumPlayers() > 2) {
-      item += ", " + ToText(efg.Payoff(outcome, efg.Players()[3]));
-      if (efg.NumPlayers() > 3) {
+    item += (" (" + 
+	     Gambit::ToText(outcome->GetPayoff<std::string>(1)) + ", " +
+	     Gambit::ToText(outcome->GetPayoff<std::string>(2)));
+    if (efg->NumPlayers() > 2) {
+      item += ", " + Gambit::ToText(outcome->GetPayoff<std::string>(3));
+      if (efg->NumPlayers() > 3) {
 	item += ",...)";
       }
       else {
@@ -126,8 +141,8 @@ dialogEditNode::dialogEditNode(wxWindow *p_parent, Node *p_node)
       item += ")";
     }
 
-    m_outcome->Append(wxString::Format(_T("%s"), (const char *) item));
-    if (efg.GetOutcome(m_node) == outcome) {
+    m_outcome->Append(wxString(item.c_str(), *wxConvCurrent));
+    if (m_node->GetOutcome() == outcome) {
       m_outcome->SetSelection(outc);
     }
   }
@@ -135,12 +150,11 @@ dialogEditNode::dialogEditNode(wxWindow *p_parent, Node *p_node)
   topSizer->Add(outcomeSizer, 0, wxALL | wxEXPAND, 5);
 
   wxBoxSizer *buttonSizer = new wxBoxSizer(wxHORIZONTAL);
+  buttonSizer->Add(new wxButton(this, wxID_CANCEL, _("Cancel")), 0, wxALL, 5);
   wxButton *okButton = new wxButton(this, wxID_OK, _("OK"));
   okButton->SetDefault();
   buttonSizer->Add(okButton, 0, wxALL, 5);
-  buttonSizer->Add(new wxButton(this, wxID_CANCEL, _("Cancel")), 0, wxALL, 5);
-  //  buttonSizer->Add(new wxButton(this, wxID_HELP, _("Help")), 0, wxALL, 5);
-  topSizer->Add(buttonSizer, 0, wxALL | wxCENTER, 5);
+  topSizer->Add(buttonSizer, 0, wxALL | wxALIGN_RIGHT, 5);
 
   SetSizer(topSizer);
   topSizer->Fit(this);
@@ -150,7 +164,7 @@ dialogEditNode::dialogEditNode(wxWindow *p_parent, Node *p_node)
   CenterOnParent();
 }
 
-Infoset *dialogEditNode::GetInfoset(void) const
+Gambit::GameInfoset dialogEditNode::GetInfoset(void) const
 {
   if (m_infoset->GetSelection() == 0) {
     return 0;
