@@ -1,7 +1,7 @@
 //
 // $Source: /cvsroot/gambit/gambit/sources/gui/dlefglayout.h,v $
-// $Date: 2002/08/27 20:29:27 $
-// $Revision: 1.2 $
+// $Date: 2005/12/12 07:17:05 $
+// $Revision: 1.4 $
 //
 // DESCRIPTION:
 // Declaration of dialog to set tree layout parameters
@@ -27,19 +27,23 @@
 #ifndef DLEFGLAYOUT_H
 #define DLEFGLAYOUT_H
 
-#include "wx/notebook.h"
-#include "treedraw.h"
+#include <wx/notebook.h>
+#include "style.h"
 
-class dialogLayout : public wxDialog {
+class gbtLayoutDialog : public wxDialog {
 private:
+  bool m_toDefaults;
   wxNotebook *m_notebook;
 
+  // Event handlers
+  void OnSetDefaults(wxCommandEvent &);
+
 public:
   // Lifecycle
-  dialogLayout(wxWindow *p_parent, const TreeDrawSettings &);
+  gbtLayoutDialog(wxWindow *p_parent, const gbtStyle &);
 
   // Data access (only valid when ShowModal() returns with wxID_OK)
-  void GetSettings(TreeDrawSettings &);
+  void GetSettings(gbtStyle &);
 };
 
 #endif  // DLEFGLAYOUT_H
