@@ -1,7 +1,7 @@
 //
 // $Source: /cvsroot/gambit/gambit/sources/gui/dlefglegend.h,v $
-// $Date: 2004/08/16 17:18:27 $
-// $Revision: 1.2.2.2 $
+// $Date: 2005/12/12 07:17:05 $
+// $Revision: 1.4 $
 //
 // DESCRIPTION:
 // Dialog for setting legends for extensive form display
@@ -27,24 +27,22 @@
 #ifndef DLEFGLEGEND_H
 #define DLEFGLEGEND_H
 
-#include "treedraw.h"
+#include "style.h"
 
-class dialogLegend : public wxDialog {
+class gbtLegendDialog : public wxDialog {
 private:
-  wxRadioBox *m_nodeAbove, *m_nodeBelow, *m_nodeAfter;
-  wxRadioBox *m_branchAbove, *m_branchBelow;
+  wxChoice *m_nodeAbove, *m_nodeBelow, *m_actionAbove, *m_actionBelow;
 
 public:
   // Lifecycle
-  dialogLegend(wxWindow *, const TreeDrawSettings &);
+  gbtLegendDialog(wxWindow *, const gbtStyle &);
 
   // Data access (only valid when ShowModal() returns with wxID_OK)
   int GetNodeAbove(void) const { return m_nodeAbove->GetSelection(); }
   int GetNodeBelow(void) const { return m_nodeBelow->GetSelection(); }
-  int GetNodeAfter(void) const { return m_nodeAfter->GetSelection(); }
 
-  int GetBranchAbove(void) const { return m_branchAbove->GetSelection(); }
-  int GetBranchBelow(void) const { return m_branchBelow->GetSelection(); }
+  int GetBranchAbove(void) const { return m_actionAbove->GetSelection(); }
+  int GetBranchBelow(void) const { return m_actionBelow->GetSelection(); }
 };
 
 #endif // DLEFGLEGEND_H
