@@ -1,7 +1,7 @@
 //
 // $Source: /cvsroot/gambit/gambit/sources/gui/dlefgreveal.cc,v $
-// $Date: 2004/08/17 17:53:50 $
-// $Revision: 1.3.2.3 $
+// $Date: 2006/01/07 05:41:25 $
+// $Revision: 1.16 $
 //
 // DESCRIPTION:
 // Dialog for revealing actions to players
@@ -24,61 +24,57 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
 
-#include "wx/wxprec.h"
+#include <wx/wxprec.h>
 #ifndef WX_PRECOMP
-#include "wx/wx.h"
+#include <wx/wx.h>
 #endif  // WX_PRECOMP
 
-#include "game/efg.h"
+#include "libgambit/libgambit.h"
 #include "dlefgreveal.h"
 
 
 //=========================================================================
-//                  dialogInfosetReveal: Member functions
+//                  gbtRevealMoveDialog: Member functions
 //=========================================================================
 
-dialogInfosetReveal::dialogInfosetReveal(wxWindow *p_parent,
-					 const efgGame &p_efg)
-  : wxDialog(p_parent, -1, _("Reveal move"), wxDefaultPosition), 
-    m_efg(p_efg)
+gbtRevealMoveDialog::gbtRevealMoveDialog(wxWindow *p_parent,
+					 gbtGameDocument *p_doc)
+  : wxDialog(p_parent, -1, _("Reveal this move to players"), 
+	     wxDefaultPosition), 
+    m_doc(p_doc)
 {
-  SetAutoLayout(true);
-
   wxBoxSizer *topSizer = new wxBoxSizer(wxVERTICAL);
 
   wxStaticBoxSizer *playerBox =
-    new wxStaticBoxSizer(new wxStaticBox(this, wxID_STATIC,
-					 _("Reveal to players")),
-			 wxHORIZONTAL);
+    new wxStaticBoxSizer(wxHORIZONTAL, this, 
+			 _("Reveal the move to players"));
 
-  wxFlexGridSizer *gridSizer = new wxFlexGridSizer(wxVERTICAL,
-						   (m_efg.NumPlayers() <= 2) ?
-						   2 : 3);
-  m_players = new wxCheckBox *[m_efg.NumPlayers()];
-  for (int pl = 1; pl <= m_efg.NumPlayers(); pl++) {
-    EFPlayer *player = m_efg.Players()[pl];
-    if (player->GetName() != "") {
-      m_players[pl-1] = new wxCheckBox(this, -1, 
-				       wxString::Format(_T("%s"), 
-							(char *) player->GetName()));
+  wxBoxSizer *boxSizer = new wxBoxSizer(wxVERTICAL);	
+
+  for (int pl = 1; pl <= m_doc->NumPlayers(); pl++) {
+    Gambit::GamePlayer player = m_doc->GetGame()->GetPlayer(pl);
+    if (player->GetLabel() != "") {
+      m_players.Append(new wxCheckBox(this, -1, 
+				      wxString(player->GetLabel().c_str(),
+					       *wxConvCurrent)));
     }
     else {
-      m_players[pl-1] = new wxCheckBox(this, -1, 
-				       wxString::Format(_T("Player %d"), pl));
+      m_players.Append(new wxCheckBox(this, -1, 
+				      wxString::Format(_T("Player %d"), pl)));
     }
-    m_players[pl-1]->SetValue(1);
-    gridSizer->Add(m_players[pl-1], 1, wxALL | wxEXPAND, 0);
+    m_players[pl]->SetValue(1);
+    m_players[pl]->SetForegroundColour(m_doc->GetStyle().GetPlayerColor(pl));
+    boxSizer->Add(m_players[pl], 1, wxALL | wxEXPAND, 0);
   }
-  playerBox->Add(gridSizer, 1, wxALL, 5);
-  topSizer->Add(playerBox, 1, wxALL | wxCENTER, 5);
+  playerBox->Add(boxSizer, 1, wxALL | wxEXPAND, 5);
+  topSizer->Add(playerBox, 1, wxALL | wxEXPAND, 5);
 
   wxBoxSizer *buttonSizer = new wxBoxSizer(wxHORIZONTAL);
+  buttonSizer->Add(new wxButton(this, wxID_CANCEL, _("Cancel")), 0, wxALL, 5);
   wxButton *okButton = new wxButton(this, wxID_OK, _("OK"));
   okButton->SetDefault();
   buttonSizer->Add(okButton, 0, wxALL, 5);
-  buttonSizer->Add(new wxButton(this, wxID_CANCEL, _("Cancel")), 0, wxALL, 5);
-  //  buttonSizer->Add(new wxButton(this, wxID_HELP, _("Help")), 0, wxALL, 5);
-  topSizer->Add(buttonSizer, 0, wxCENTER | wxALL, 5);
+  topSizer->Add(buttonSizer, 0, wxALL | wxALIGN_RIGHT, 5);
 
   SetSizer(topSizer);
   topSizer->Fit(this);
@@ -87,18 +83,13 @@ dialogInfosetReveal::dialogInfosetReveal(wxWindow *p_parent,
   CenterOnParent();
 }
 
-dialogInfosetReveal::~dialogInfosetReveal()
+Gambit::Array<Gambit::GamePlayer> gbtRevealMoveDialog::GetPlayers(void) const
 {
-  delete [] m_players;
-}
+  Gambit::Array<Gambit::GamePlayer> players;
 
-gArray<EFPlayer *> dialogInfosetReveal::GetPlayers(void) const
-{
-  gBlock<EFPlayer *> players;
-
-  for (int pl = 1; pl <= m_efg.NumPlayers(); pl++) {
-    if (m_players[pl-1]->GetValue()) {
-      players.Append(m_efg.Players()[pl]);
+  for (int pl = 1; pl <= m_doc->NumPlayers(); pl++) {
+    if (m_players[pl]->GetValue()) {
+      players.Append(m_doc->GetGame()->GetPlayer(pl));
     }
   }
 
