@@ -1,7 +1,7 @@
 //
 // $Source: /cvsroot/gambit/gambit/sources/gui/dlefgreveal.h,v $
-// $Date: 2002/08/27 20:29:28 $
-// $Revision: 1.5 $
+// $Date: 2006/01/07 05:41:25 $
+// $Revision: 1.12 $
 //
 // DESCRIPTION:
 // Dialog for revealing actions to players
@@ -27,18 +27,19 @@
 #ifndef DLEFGREVEAL_H
 #define DLEFGREVEAL_H
 
-class dialogInfosetReveal : public wxDialog {
+#include "gamedoc.h"
+
+class gbtRevealMoveDialog : public wxDialog {
 private:
-  const efgGame &m_efg;
-  wxCheckBox **m_players;
+  gbtGameDocument *m_doc;
+  Gambit::Array<wxCheckBox *> m_players;
 
 public:
   // Lifecycle
-  dialogInfosetReveal(wxWindow *, const efgGame &);
-  virtual ~dialogInfosetReveal();
+  gbtRevealMoveDialog(wxWindow *, gbtGameDocument *);
 
   // Data access (only valid when ShowModal() returns with wxID_OK)
-  gArray<EFPlayer *> GetPlayers(void) const;
+  Gambit::Array<Gambit::GamePlayer> GetPlayers(void) const;
 };
 
 #endif  // DLEFGREVEAL_H
