@@ -1,7 +1,7 @@
 //
 // $Source: /cvsroot/gambit/gambit/sources/gui/efglayout.h,v $
-// $Date: 2004/08/16 17:18:28 $
-// $Revision: 1.16.2.8 $
+// $Date: 2006/01/07 05:41:25 $
+// $Revision: 1.40 $
 //
 // DESCRIPTION:
 // Interface to tree layout representation
@@ -27,23 +27,21 @@
 #ifndef EFGLAYOUT_H
 #define EFGLAYOUT_H
 
-#include "base/base.h"
-#include "treedraw.h"
-#include "efgconst.h"
-#include "game/efg.h"
+#include "libgambit/libgambit.h"
+#include "style.h"
+#include "gamedoc.h"
 
-class NodeEntry {
+class gbtNodeEntry {
 private:
-  Node *m_node;        // the corresponding node in the game
-  NodeEntry *m_parent; // parent node
+  Gambit::GameNode m_node;        // the corresponding node in the game
+  gbtNodeEntry *m_parent; // parent node
   int m_x, m_y;        // Cartesian coordinates of node
-  NodeEntry *m_nextMember;  // entry of next information set member 
+  gbtNodeEntry *m_nextMember;  // entry of next information set member 
   bool m_inSupport;    // true if node reachable in current support
-  bool m_selected;    // true if node is selected
-  bool m_cursor;      // true if node is 'cursor'
-  bool m_cut;         // true if node is in a 'cut' subtree
-  bool m_subgameRoot, m_subgameMarked;
   int m_size;         // horizontal size of the node
+  mutable wxRect m_outcomeRect;
+  mutable Gambit::Array<wxRect> m_payoffRect;
+  mutable wxRect m_branchAboveRect, m_branchBelowRect;
   int m_token;        // token to draw for node
   wxColour m_color;   // color of node
 
@@ -53,29 +51,31 @@ private:
 
   int m_level;        // depth of the node in tree
   int m_sublevel;     // # of the infoset line on this level
-  gNumber m_actionProb;  // probability incoming action is taken
+  double m_actionProb;  // probability incoming action is taken
 
-  wxString m_nodeAboveLabel, m_nodeBelowLabel, m_nodeRightLabel;
+  wxString m_nodeAboveLabel, m_nodeBelowLabel;
   wxString m_branchAboveLabel, m_branchBelowLabel;
 
-  wxFont m_nodeAboveFont, m_nodeBelowFont, m_nodeRightFont;
+  wxFont m_nodeAboveFont, m_nodeBelowFont;
   wxFont m_branchAboveFont, m_branchBelowFont;
 
+  gbtStyle *m_style;
+
 public:
-  NodeEntry(Node *p_parent);
+  gbtNodeEntry(Gambit::GameNode p_parent);
 
-  Node *GetNode(void) const { return m_node; }
+  Gambit::GameNode GetNode(void) const { return m_node; }
 
-  NodeEntry *GetParent(void) const { return m_parent; }
-  void SetParent(NodeEntry *p_parent) { m_parent = p_parent; }
+  gbtNodeEntry *GetParent(void) const { return m_parent; }
+  void SetParent(gbtNodeEntry *p_parent) { m_parent = p_parent; }
 
   int X(void) const { return m_x; }
   void SetX(int p_x) { m_x = p_x; }
   int Y(void) const { return m_y; }
   void SetY(int p_y) { m_y = p_y; }
 
-  NodeEntry *GetNextMember(void) const { return m_nextMember; }
-  void SetNextMember(NodeEntry *p_member) { m_nextMember = p_member; }
+  gbtNodeEntry *GetNextMember(void) const { return m_nextMember; }
+  void SetNextMember(gbtNodeEntry *p_member) { m_nextMember = p_member; }
 
   bool InSupport(void) const { return m_inSupport; }
   void SetInSupport(bool p_inSupport) { m_inSupport = p_inSupport; }
@@ -85,21 +85,6 @@ public:
   const wxColour &GetColor(void) const { return m_color; }
   void SetColor(const wxColour &p_color) { m_color = p_color; }
 
-  bool IsCursor(void) const { return m_cursor; }
-  void SetCursor(bool p_cursor);
-
-  bool IsSelected(void) const { return m_selected; }
-  void SetSelected(bool p_selected) { m_selected = p_selected; }
-
-  bool IsCut(void) const { return m_cut; }
-  void SetCut(bool p_cut) { m_cut = p_cut; }
-
-  bool IsSubgameRoot(void) const { return m_subgameRoot; }
-  void SetSubgameRoot(bool p_root) { m_subgameRoot = p_root; }
-  
-  bool IsSubgameMarked(void) const { return m_subgameMarked; }
-  void SetSubgameMarked(bool p_marked) { m_subgameMarked = p_marked; }
-
   int GetSize(void) const { return m_size; }
   void SetSize(int p_size) { m_size = p_size; }
 
@@ -129,10 +114,6 @@ public:
   void SetNodeBelowLabel(const wxString &p_label)
     { m_nodeBelowLabel = p_label; }
 
-  const wxString &GetNodeRightLabel(void) const { return m_nodeRightLabel; }
-  void SetNodeRightLabel(const wxString &p_label)
-    { m_nodeRightLabel = p_label; }
-
   const wxString &GetBranchAboveLabel(void) const 
     { return m_branchAboveLabel; }
   void SetBranchAboveLabel(const wxString &p_label)
@@ -149,83 +130,91 @@ public:
   const wxFont &GetNodeBelowFont(void) const { return m_nodeBelowFont; }
   void SetNodeBelowFont(const wxFont &p_font) { m_nodeBelowFont = p_font; }
 
-  const wxFont &GetNodeRightFont(void) const { return m_nodeRightFont; }
-  void SetNodeRightFont(const wxFont &p_font) { m_nodeRightFont = p_font; }
-
   const wxFont &GetBranchAboveFont(void) const { return m_branchAboveFont; }
   void SetBranchAboveFont(const wxFont &p_font) { m_branchAboveFont = p_font; }
 
   const wxFont &GetBranchBelowFont(void) const { return m_branchBelowFont; }
   void SetBranchBelowFont(const wxFont &p_font) { m_branchBelowFont = p_font; }
 
-  const gNumber &GetActionProb(void) const { return m_actionProb; }
-  void SetActionProb(const gNumber &p_prob) { m_actionProb = p_prob; }
+  const double &GetActionProb(void) const { return m_actionProb; }
+  void SetActionProb(const double &p_prob) { m_actionProb = p_prob; }
+
+  void SetStyle(gbtStyle *p_style) { m_style = p_style; }
 
   bool NodeHitTest(int p_x, int p_y) const;
+  bool OutcomeHitTest(int p_x, int p_y) const
+  { return (m_outcomeRect.Inside(p_x, p_y)); }
+  bool BranchAboveHitTest(int p_x, int p_y) const
+  { return (m_branchAboveRect.Inside(p_x, p_y)); }
+  bool BranchBelowHitTest(int p_x, int p_y) const
+  { return (m_branchBelowRect.Inside(p_x, p_y)); }
 
-  void Draw(wxDC &) const;
+  const wxRect &GetOutcomeExtent(void) const { return m_outcomeRect; }
+  const wxRect &GetPayoffExtent(int pl) const { return m_payoffRect[pl]; }
+
+  void Draw(wxDC &, Gambit::GameNode selection, bool p_noHints) const;
   void DrawIncomingBranch(wxDC &) const;
+  void DrawOutcome(wxDC &, bool p_noHints) const;
 };
 
-class TreeWindow;
+class gbtEfgDisplay;
 
-class efgTreeLayout {
+class gbtTreeLayout : public gbtGameView {
 private:
-  efgGame &m_efg;
-  TreeWindow *m_parent;
-  gBlock<NodeEntry *> m_nodeList;
-  int m_maxX, m_maxY, m_maxLevel;
+  gbtEfgDisplay *m_parent;
+  Gambit::Array<gbtNodeEntry *> m_nodeList;
+  mutable int m_maxX, m_maxY, m_maxLevel;
   int m_infosetSpacing;
 
   const int c_leftMargin, c_topMargin;
 
-  NodeEntry *GetEntry(Node *) const;
+  gbtNodeEntry *GetEntry(Gambit::GameNode) const;
 
-  NodeEntry *NextInfoset(NodeEntry *);
-  void CheckInfosetEntry(NodeEntry *);
+  gbtNodeEntry *NextInfoset(gbtNodeEntry *);
+  void CheckInfosetEntry(gbtNodeEntry *);
 
-  void BuildNodeList(Node *, const EFSupport &, int);
+  void BuildNodeList(Gambit::GameNode, const Gambit::BehavSupport &, int);
 
-  int LayoutSubtree(Node *, const EFSupport &, int &, int &, int &);
-  void FillInfosetTable(Node *, const EFSupport &);
+  int LayoutSubtree(Gambit::GameNode, const Gambit::BehavSupport &, int &, int &, int &);
+  void FillInfosetTable(Gambit::GameNode, const Gambit::BehavSupport &);
   void UpdateTableInfosets(void);
   void UpdateTableParents(void);
 
-  wxString CreateNodeAboveLabel(const NodeEntry *) const;
-  wxString CreateNodeBelowLabel(const NodeEntry *) const;
-  wxString CreateNodeRightLabel(const NodeEntry *) const;
-  wxString CreateBranchAboveLabel(const NodeEntry *) const;
-  wxString CreateBranchBelowLabel(const NodeEntry *) const;
+  wxString CreateNodeLabel(const gbtNodeEntry *, int) const;
+  wxString CreateBranchLabel(const gbtNodeEntry *, int) const;
 
-  void RenderSubtree(wxDC &dc) const;
+  void RenderSubtree(wxDC &dc, bool p_noHints) const;
+
+  // Overriding gbtGameView members
+  void OnUpdate(void) { }
 
 public:
-  efgTreeLayout(efgGame &, TreeWindow *);
-  virtual ~efgTreeLayout() { }
+  gbtTreeLayout(gbtEfgDisplay *p_parent, gbtGameDocument *p_doc);
+  virtual ~gbtTreeLayout() { }
 
-  Node *PriorSameLevel(Node *) const;
-  Node *NextSameLevel(Node *) const;
+  Gambit::GameNode PriorSameLevel(Gambit::GameNode) const;
+  Gambit::GameNode NextSameLevel(Gambit::GameNode) const;
 
-  void BuildNodeList(const EFSupport &);
-  void Layout(const EFSupport &);
+  void BuildNodeList(const Gambit::BehavSupport &);
+  void Layout(const Gambit::BehavSupport &);
   void GenerateLabels(void);
 
-  void SetCutNode(Node *, bool);
-
   // The following member functions are for temporary compatibility only
-  NodeEntry *GetNodeEntry(Node *p_node) const
+  gbtNodeEntry *GetNodeEntry(Gambit::GameNode p_node) const
     { return GetEntry(p_node); }
-  NodeEntry *GetValidParent(Node *);
-  NodeEntry *GetValidChild(Node *);
+  gbtNodeEntry *GetValidParent(Gambit::GameNode);
+  gbtNodeEntry *GetValidChild(Gambit::GameNode);
 
   int MaxX(void) const { return m_maxX; }
   int MaxY(void) const { return m_maxY; }
 
-  Node *NodeHitTest(int, int) const;
-  Node *BranchHitTest(int, int) const;
-  Node *InfosetHitTest(int, int) const;
+  Gambit::GameNode NodeHitTest(int, int) const;
+  Gambit::GameNode OutcomeHitTest(int, int) const;
+  Gambit::GameNode BranchAboveHitTest(int, int) const;
+  Gambit::GameNode BranchBelowHitTest(int, int) const;
+  Gambit::GameNode InfosetHitTest(int, int) const;
 
-  void Render(wxDC &) const;
+  void Render(wxDC &, bool p_noHints) const;
 };
 
 #endif  // EFGLAYOUT_H
