@@ -1,10 +1,10 @@
 //
 // $Source: /cvsroot/gambit/gambit/sources/gui/valnumber.cc,v $
-// $Date: 2004/08/17 17:53:52 $
-// $Revision: 1.5.2.3 $
+// $Date: 2006/01/11 15:27:14 $
+// $Revision: 1.14 $
 //
 // DESCRIPTION:
-// wxValidator specialization to gNumber
+// wxValidator specialization to gbtNumber
 //
 // This file is part of Gambit
 // Copyright (c) 2002, The Gambit Project
@@ -24,24 +24,20 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
 
-#include "wx/wxprec.h"
-#ifndef WX_PRECOMP
-#include "wx/wx.h"
-#endif  // WX_PRECOMP
-
-#if defined(__GNUG__) && !defined(__APPLE_CC__)
-#pragma implementation "valnumber.h"
-#endif  // __GNUG__
-
-#include "valnumber.h"
-#include "base/base.h"
-
 #include <ctype.h>
 #include <string.h>
 #include <stdlib.h>
 
-BEGIN_EVENT_TABLE(gNumberValidator, wxValidator)
-  EVT_CHAR(gNumberValidator::OnChar)
+#include <wx/wxprec.h>
+#ifndef WX_PRECOMP
+#include <wx/wx.h>
+#endif  // WX_PRECOMP
+
+#include "libgambit/libgambit.h"
+#include "valnumber.h"
+
+BEGIN_EVENT_TABLE(gbtNumberValidator, wxValidator)
+  EVT_CHAR(gbtNumberValidator::OnChar)
 END_EVENT_TABLE()
 
 static bool IsNumeric(const wxString &p_value)
@@ -73,32 +69,32 @@ static bool IsNumeric(const wxString &p_value)
 }
 
 //------------------------------------------------------------------------
-//               class gNumberValidator: Member functions
+//               class gbtNumberValidator: Member functions
 //------------------------------------------------------------------------
 
-gNumberValidator::gNumberValidator(wxString *p_value)
+gbtNumberValidator::gbtNumberValidator(wxString *p_value)
   : m_stringValue(p_value), m_hasMin(false), m_hasMax(false)
 { }
 
-gNumberValidator::gNumberValidator(wxString *p_value,
-				   const gNumber &p_minValue)
+gbtNumberValidator::gbtNumberValidator(wxString *p_value,
+				       const Gambit::Rational &p_minValue)
   : m_stringValue(p_value), m_hasMin(true), m_hasMax(false),
     m_minValue(p_minValue)
 { }
 
-gNumberValidator::gNumberValidator(wxString *p_value,
-				   const gNumber &p_minValue,
-				   const gNumber &p_maxValue)
+gbtNumberValidator::gbtNumberValidator(wxString *p_value,
+				       const Gambit::Rational &p_minValue,
+				       const Gambit::Rational &p_maxValue)
   : m_stringValue(p_value), m_hasMin(true), m_hasMax(true),
     m_minValue(p_minValue), m_maxValue(p_maxValue)
 { }
 
-gNumberValidator::gNumberValidator(const gNumberValidator &p_validator)
+gbtNumberValidator::gbtNumberValidator(const gbtNumberValidator &p_validator)
 {
   Copy(p_validator);
 }
 
-bool gNumberValidator::Copy(const gNumberValidator &p_validator)
+bool gbtNumberValidator::Copy(const gbtNumberValidator &p_validator)
 {
   wxValidator::Copy(p_validator);
   m_stringValue = p_validator.m_stringValue;
@@ -109,7 +105,7 @@ bool gNumberValidator::Copy(const gNumberValidator &p_validator)
   return true;
 }
 
-bool gNumberValidator::Validate(wxWindow *p_parent)
+bool gbtNumberValidator::Validate(wxWindow *p_parent)
 {
   if (!m_stringValue) {
     return false;
@@ -131,12 +127,12 @@ bool gNumberValidator::Validate(wxWindow *p_parent)
     return false;
   }
 
-  if ((m_hasMin && ToNumber((const char *) value.mb_str()) < m_minValue) ||
-      (m_hasMax && ToNumber((const char *) value.mb_str()) > m_maxValue)) {
+  if ((m_hasMin && Gambit::ToNumber((const char *) value.mb_str()) < m_minValue) ||
+      (m_hasMax && Gambit::ToNumber((const char *) value.mb_str()) > m_maxValue)) {
     wxMessageBox(_T("The value ") + value + _T(" in ") +
 		 m_validatorWindow->GetName() + _T(" is out of the range [") +
-		 wxString::Format(_T("%s"), (char *) ToText(m_minValue)) + _T(", ") + 
-		 wxString::Format(_T("%s"), (char *) ToText(m_maxValue)) + _T("]."),
+		 wxString(ToText(m_minValue).c_str(), *wxConvCurrent) + _T(", ") + 
+		 wxString(ToText(m_maxValue).c_str(), *wxConvCurrent) + _T("]."),
 		 _("Error"), wxOK | wxICON_EXCLAMATION, p_parent);
     m_validatorWindow->SetFocus();
     return false;
@@ -145,7 +141,7 @@ bool gNumberValidator::Validate(wxWindow *p_parent)
   return true;
 }
 
-bool gNumberValidator::TransferToWindow(void)
+bool gbtNumberValidator::TransferToWindow(void)
 {
   if (!m_stringValue) {
     return false;
@@ -157,7 +153,7 @@ bool gNumberValidator::TransferToWindow(void)
   return true;
 }
 
-bool gNumberValidator::TransferFromWindow(void)
+bool gbtNumberValidator::TransferFromWindow(void)
 {
   if (!m_stringValue) {
     return false;
@@ -169,7 +165,7 @@ bool gNumberValidator::TransferFromWindow(void)
   return TRUE;
 }
 
-void gNumberValidator::OnChar(wxKeyEvent &p_event)
+void gbtNumberValidator::OnChar(wxKeyEvent &p_event)
 {
   if (m_validatorWindow) {
     int keyCode = (int) p_event.GetKeyCode();
@@ -185,6 +181,45 @@ void gNumberValidator::OnChar(wxKeyEvent &p_event)
 
       return;
     }
+
+    wxTextCtrl *control = (wxTextCtrl *) m_validatorWindow;
+    wxString value = control->GetValue();
+
+    if ((keyCode == '.' || keyCode == '/') && 
+	(value.Find('.') != -1 || value.Find('/') != -1)) {
+      // At most one slash or decimal point is allowed
+      if (!wxValidator::IsSilent())  wxBell();
+      return;
+    }
+
+    if (keyCode == '/' && 
+	(control->GetInsertionPoint() == 0 ||
+	 (control->GetInsertionPoint() == 1 && value == wxT("-")))) {
+      // Can't start with a slash
+      if (!wxValidator::IsSilent())  wxBell();
+      return;
+    }
+
+    if (keyCode == '-') {
+      // Only permit minus signs at the start of the text
+      long start, end;
+      control->GetSelection(&start, &end);
+      
+      if (start == end) {
+	// No selection; just see if inserting is OK
+	if (control->GetInsertionPoint() != 0) {
+	  if (!wxValidator::IsSilent())  wxBell();
+	  return;
+	}
+      }
+      else {
+	// There is a selection; is selection at beginning?
+	if (start != 0) {
+	  if (!wxValidator::IsSilent())  wxBell();
+	  return;
+	}	
+      }
+    }
   }
 
   p_event.Skip();
